firewall

package module
v0.0.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2019 License: MIT Imports: 11 Imported by: 0

README

canal

This is likely to destroy things you love in it's current state. Working on it.

This starting to actually do what it's supposed to and it will start to become something like stable soon.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AppendFile

func AppendFile(filename, text string, perms os.FileMode) error

func Command

func Command(command string, args ...string) (string, error)

func DarwinServerSetup

func DarwinServerSetup(iface, gface string) error

func DefaultIface

func DefaultIface() (string, error)

func FlushTables added in v0.0.15

func FlushTables() error

func IfIP

func IfIP(INTERFACE string) (net.IP, error)

func LinuxCheckIPRules

func LinuxCheckIPRules() bool

func LinuxFindNext added in v0.0.11

func LinuxFindNext() string

func LinuxFindNum added in v0.0.11

func LinuxFindNum() string

func LinuxFindTag added in v0.0.20

func LinuxFindTag() string

func LinuxFlushIPTables

func LinuxFlushIPTables() error

Sets up specific marking for VPN-Exempt or VPN-enabled users.

func LinuxServerSetup

func LinuxServerSetup(iface, gface string) error

func LinuxSetupIPTables

func LinuxSetupIPTables(LANIP, USER string) error

Sets up specific marking for VPN-Exempt or VPN-enabled users.

func LinuxSetupIPTablesExemptUser

func LinuxSetupIPTablesExemptUser(LANIP, USER, LANINTERFACE, VPNINTERFACE string) error

func LinuxSetupIPTablesTagUser

func LinuxSetupIPTablesTagUser(LANIP, USER, VPNINTERFACE string) error

func LinuxSetupRoutingTable

func LinuxSetupRoutingTable(USER string) error

func LinuxSetupRoutingTables

func LinuxSetupRoutingTables(gate net.IP, USER, INTERFACE string, exempt bool, VPNINTERFACE string) error

func ServerSetup

func ServerSetup(iface, gface string) error

func Setup

func Setup(user, iface string, exempt bool, vface string) error

func WindowsCheckIPRules

func WindowsCheckIPRules() bool

func WindowsFindExePath

func WindowsFindExePath(APP string) (string, error)

func WindowsServerSetup

func WindowsServerSetup(iface, gface string) error

func WindowsSetupNetSH

func WindowsSetupNetSH(LANIP, USER string) error

Sets up specific marking for VPN-Exempt or VPN-enabled users.

func WindowsSetupNetSHExemptApp

func WindowsSetupNetSHExemptApp(LANIP, APP, LANINTERFACE, VPNINTERFACE string) error

func WindowsSetupNetSHSecureSetup

func WindowsSetupNetSHSecureSetup(LANIP, USER, VPNINTERFACE string) error

func WindowsSetupRoutingTable

func WindowsSetupRoutingTable(USER string) error

func WindowsSetupRoutingTables

func WindowsSetupRoutingTables(gate net.IP, USER, INTERFACE string, exempt bool, VPNINTERFACE string) error

Types

This section is empty.

Directories

Path Synopsis

Jump to